@@ -116,6 +116,12 @@ class MUC(BaseModule):
         properties.muc_jid = properties.jid.new_as_bare()
         properties.muc_nickname = properties.jid.resource
 
+        occupant_id = stanza.getTagAttr('occupant-id',
+                                        'id',
+                                        namespace=Namespace.OCCUPANT_ID)
+
+        properties.occupant_id = occupant_id
+
     def _process_muc_user_presence(self, _client, stanza, properties):
         muc_user = stanza.getTag('x', namespace=Namespace.MUC_USER)
         if muc_user is None:
@@ -123,6 +129,13 @@ class MUC(BaseModule):
         properties.from_muc = True
         properties.muc_jid = properties.jid.new_as_bare()
 
+
+        occupant_id = stanza.getTagAttr('occupant-id',
+                                        'id',
+                                        namespace=Namespace.OCCUPANT_ID)
+
+        properties.occupant_id = occupant_id
+
         destroy = muc_user.getTag('destroy')
         if destroy is not None:
             alternate = destroy.getAttr('jid')
@@ -192,6 +205,12 @@ class MUC(BaseModule):
         properties.muc_jid = properties.jid.new_as_bare()
         properties.muc_nickname = properties.jid.resource
 
+        occupant_id = stanza.getTagAttr('occupant-id',
+                                        'id',
+                                        namespace=Namespace.OCCUPANT_ID)
+
+        properties.occupant_id = occupant_id
+
         muc_user = stanza.getTag('x', namespace=Namespace.MUC_USER)
         if muc_user is not None:
             try:
@@ -209,7 +228,7 @@ class MUC(BaseModule):
                 properties.muc_ofrom = JID.from_string(address.getAttr('jid'))
 
     def _process_message_after_decryption(self, _client, _stanza, properties):
-        if properties.body is None and properties.subject:
+        if properties.body is None and properties.subject is not None:
             properties.muc_subject = MucSubject(
                 text=properties.subject,
                 author=properties.muc_nickname,
@@ -220,6 +239,12 @@ class MUC(BaseModule):
         if muc_user is None:
             return
 
+        occupant_id = stanza.getTagAttr('occupant-id',
+                                        'id',
+                                        namespace=Namespace.OCCUPANT_ID)
+
+        properties.occupant_id = occupant_id
+
         # MUC Private message
         if (properties.type.is_chat or
                 properties.type.is_error and
