@@ -34,8 +34,9 @@ class _Namespaces:
     BLOCKING: str = 'urn:xmpp:blocking'
     BOB: str = 'urn:xmpp:bob'
     BOOKMARKS: str = 'storage:bookmarks'
-    BOOKMARKS_2: str = 'urn:xmpp:bookmarks:0'
-    BOOKMARKS_COMPAT: str = 'urn:xmpp:bookmarks:0#compat'
+    BOOKMARKS_1: str = 'urn:xmpp:bookmarks:1'
+    BOOKMARKS_COMPAT: str = 'urn:xmpp:bookmarks:1#compat'
+    BOOKMARKS_COMPAT_PEP: str = 'urn:xmpp:bookmarks:1#compat-pep'
     BOOKMARK_CONVERSION: str = 'urn:xmpp:bookmarks-conversion:0'
     BROWSE: str = 'jabber:iq:browse'
     BYTESTREAM: str = 'http://jabber.org/protocol/bytestreams'
@@ -54,12 +55,15 @@ class _Namespaces:
     DATA_VALIDATE: str = 'http://jabber.org/protocol/xdata-validate'
     DELAY: str = 'jabber:x:delay'
     DELAY2: str = 'urn:xmpp:delay'
+    DELIMITER: str = 'roster:delimiter'
     DISCO: str = 'http://jabber.org/protocol/disco'
     DISCO_INFO: str = 'http://jabber.org/protocol/disco#info'
     DISCO_ITEMS: str = 'http://jabber.org/protocol/disco#items'
     DOMAIN_BASED_NAME: str = 'urn:xmpp:domain-based-name:1'
     EME: str = 'urn:xmpp:eme:0'
     ENCRYPTED: str = 'jabber:x:encrypted'
+    FASTEN: str = 'urn:xmpp:fasten:0'
+    FILE_METADATA: str = 'urn:xmpp:file:metadata:0'
     FORWARD: str = 'urn:xmpp:forward:0'
     FRAMING: str = 'urn:ietf:params:xml:ns:xmpp-framing'
     GATEWAY: str = 'jabber:iq:gateway'
@@ -96,6 +100,8 @@ class _Namespaces:
     LOCATION: str = 'http://jabber.org/protocol/geoloc'
     MAM_1: str = 'urn:xmpp:mam:1'
     MAM_2: str = 'urn:xmpp:mam:2'
+    MESSAGE_MODERATE: str = 'urn:xmpp:message-moderate:0'
+    MESSAGE_RETRACT: str = 'urn:xmpp:message-retract:0'
     MOOD: str = 'http://jabber.org/protocol/mood'
     MSG_HINTS: str = 'urn:xmpp:hints'
     MUCLUMBUS: str = 'https://xmlns.zombofant.net/muclumbus/search/1.0'
@@ -108,6 +114,7 @@ class _Namespaces:
     MUC_REQUEST: str = 'http://jabber.org/protocol/muc#request'
     MUC_INFO: str = 'http://jabber.org/protocol/muc#roominfo'
     NICK: str = 'http://jabber.org/protocol/nick'
+    OCCUPANT_ID: str = 'urn:xmpp:occupant-id:0'
     OMEMO_TEMP: str = 'eu.siacs.conversations.axolotl'
     OMEMO_TEMP_BUNDLE: str = 'eu.siacs.conversations.axolotl.bundles'
     OMEMO_TEMP_DL: str = 'eu.siacs.conversations.axolotl.devicelist'
@@ -121,10 +128,12 @@ class _Namespaces:
     PUBKEY_PUBKEY: str = 'urn:xmpp:pubkey:2'
     PUBKEY_REVOKE: str = 'urn:xmpp:revoke:2'
     PUBSUB: str = 'http://jabber.org/protocol/pubsub'
+    PUBSUB_ERROR: str = 'http://jabber.org/protocol/pubsub#errors'
     PUBSUB_CONFIG: str = 'http://jabber.org/protocol/pubsub#node_config'
     PUBSUB_EVENT: str = 'http://jabber.org/protocol/pubsub#event'
     PUBSUB_OWNER: str = 'http://jabber.org/protocol/pubsub#owner'
     PUBSUB_PUBLISH_OPTIONS: str = 'http://jabber.org/protocol/pubsub#publish-options'
+    PUBSUB_NODE_MAX: str = 'http://jabber.org/protocol/pubsub#config-node-max'
     RECEIPTS: str = 'urn:xmpp:receipts'
     REGISTER: str = 'jabber:iq:register'
     REGISTER_FEATURE: str = 'http://jabber.org/features/iq-register'
@@ -135,29 +144,37 @@ class _Namespaces:
     ROSTER_VER: str = 'urn:xmpp:features:rosterver'
     RSM: str = 'http://jabber.org/protocol/rsm'
     SASL: str = 'urn:ietf:params:xml:ns:xmpp-sasl'
+    SASL2: str = 'urn:xmpp:sasl:1'
     SEARCH: str = 'jabber:iq:search'
     SECLABEL: str = 'urn:xmpp:sec-label:0'
     SECLABEL_CATALOG: str = 'urn:xmpp:sec-label:catalog:2'
     SESSION: str = 'urn:ietf:params:xml:ns:xmpp-session'
+    SFS: str = 'urn:xmpp:sfs:0'
     SID: str = 'urn:xmpp:sid:0'
     SIGNED: str = 'jabber:x:signed'
     SIMS: str = 'urn:xmpp:sims:1'
     STANZAS: str = 'urn:ietf:params:xml:ns:xmpp-stanzas'
+    STICKERS: str = 'urn:xmpp:stickers:0'
     STREAM: str = 'http://affinix.com/jabber/stream'
     STREAMS: str = 'http://etherx.jabber.org/streams'
     STREAM_MGMT: str = 'urn:xmpp:sm:3'
     STYLING: str = 'urn:xmpp:styling:0'
     TIME_REVISED: str = 'urn:xmpp:time'
+    TIME: str = 'urn:xmpp:time'
     TLS: str = 'urn:ietf:params:xml:ns:xmpp-tls'
     TUNE: str = 'http://jabber.org/protocol/tune'
+    URL_DATA: str = 'http://jabber.org/protocol/url-data'
     VCARD: str = 'vcard-temp'
     VCARD_UPDATE: str = 'vcard-temp:x:update'
     VCARD_CONVERSION: str = 'urn:xmpp:pep-vcard-conversion:0'
+    VCARD4: str = 'urn:ietf:params:xml:ns:vcard-4.0'
+    VCARD4_PUBSUB: str = 'urn:xmpp:vcard4'
     VERSION: str = 'jabber:iq:version'
     XHTML_IM: str = 'http://jabber.org/protocol/xhtml-im'
     XHTML: str = 'http://www.w3.org/1999/xhtml'
     XMPP_STREAMS: str = 'urn:ietf:params:xml:ns:xmpp-streams'
     X_OOB: str = 'jabber:x:oob'
+    XRD: str = 'http://docs.oasis-open.org/ns/xri/xrd-1.0'
 
 
-Namespace = _Namespaces()
+Namespace: _Namespaces = _Namespaces()
